.. include:: ../../README.rst

User Guide
===========

.. toctree::
  :maxdepth: 2

  Workflow <workflow>
  Usage <usage>
  HTTP API <http-api>
  Troubleshooting <troubleshooting>

Admin Guide
===========

.. toctree::
  :maxdepth: 2

  Installation <install>

Developer Guide
===============

.. toctree::
  :maxdepth: 2

  Contributing <contributing>

Python API
----------

.. toctree::
  :maxdepth: 1

  api/autoindex

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
